==> spip_3.0.8.orig.tar.xz: spip-3.0.8.orig/plugins-dist/forum/lang/forum_sk.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/forum?lang_cible=sk
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'aucun_message_forum' => 'Žiaden príspevok v diskusnom fóre',

	// B
	'bouton_radio_articles_futurs' => 'len pre budúce články (žiadna zmena databázy).',
	'bouton_radio_articles_tous' => 'pre všetky články bez výnimky.',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'pre všetky články, okrem tých s deaktivovanými diskusnými fórami.',
	'bouton_radio_enregistrement_obligatoire' => 'Vyžaduje sa registrácia (
  používatelia sa musia zaregistrovať uvedením svojej e-mailovej adresy predtým,
  ako budú môcť posielať príspevky).',
	'bouton_radio_moderation_priori' => 'Kontrola pred zverejnením (príspevky sa zobrazia až potom, čo ich
 schvália administrátori).',
	'bouton_radio_modere_abonnement' => 'Vyžaduje sa registrácia',
	'bouton_radio_modere_posteriori' => 'kontrola po zverejnení',
	'bouton_radio_modere_priori' => 'kontrola pred zverejnením',
	'bouton_radio_publication_immediate' => 'Okamžité publikovanie príspevkov
 (príspevky sa zobrazia len čo budú odoslané; ak bude treba, administrátori
 ich môžu potom odstrániť).',

	// D
	'documents_interdits_forum' => 'Dokumenty nie sú v tomto diskusnom fóre povolené',

	// E
	'erreur_enregistrement_message' => 'Váš príspevok sa z technických príčin nepodarilo uložiť.',

	// F
	'form_pet_message_commentaire' => 'Nejaký príspevok alebo komentáre?',
	'forum' => 'Diskusné fórum',
	'forum_acces_refuse' => 'K týmto diskusným fóram už viac nemáte prístup.',
	'forum_attention_dix_caracteres' => '<b>Upozornenie!</b> Váš príspevok musí mať aspoň 10 znakok.',
	'forum_attention_message_non_poste' => 'Pozor, neodoslali ste svoj príspevok!',
	'forum_attention_nb_caracteres_mini' => '<b>Pozor!</b> Váš príspevok musí mať aspoň @min@ znakov.',
	'forum_attention_trois_caracteres' => '<b>Upozornenie!</b> Názov musí mať aspoň 3 znaky.',
	'forum_attention_trop_caracteres' => '<b>Pozor!</b> váš príspevok je pridlhý (@compte@ znamkov): aby ste ho mohli uložiť, príspevok nesmie mať viac ako @max@ znakov.',
	'forum_avez_selectionne' => 'Vybrali ste:',
	'forum_cliquer_retour' => 'Kliknite <a href=\'@retour_forum@\'>sem,</a> aby ste mohli pokračovať.',
	'forum_forum' => 'diskusné fórum',
	'forum_info_modere' => 'Toto diskusné fórum sa kontroluje pred zverejnením: váš príspevok sa zobrazí až potom, čo ho potvrdí administrátor stránky.',
	'forum_lien_hyper' => 'Hypertextový odkaz',
	'forum_message' => 'Váš príspevok',
	'forum_message_definitif' => 'Koniec úprav: poslať príspevok',
	'forum_message_trop_long' => 'Vaša správa je pridlhá. Maximálna dĺžka je 20 000 znakov.',
	'forum_ne_repondez_pas' => 'Neodpovedajte na tento mejl priamo - prosím, použite diskusné fórum:',
	'forum_page_url' => '(If your message refers to an article published on the web or to a page providing further information, please enter the title of the page and its URL below).',
	'forum_permalink' => 'Trvalý odkaz na komentár',
	'forum_poste_par' => 'Príspevky @parauteur@ k vášmu článku "@titre@".', # MODIF
	'forum_poste_par_court' => 'Message posté@parauteur@.', # NEW
	'forum_poste_par_generique' => 'Message posté@parauteur@ (@objet@ « @titre@ »).', # NEW
	'forum_qui_etes_vous' => 'Kto ste?',
	'forum_saisie_texte_info' => 'Tento formulár akceptuje skratky SPIPu <code>[-&gt;url] {{tučné}} {kurzíva} &lt;citácia&gt; &lt;kód&gt;</code> a kód HTML <code>&lt;q&gt; &lt;del&gt; &lt;ins&gt;.</code> Ak chcete vytvoriť odseky, jednoducho vynechajte niekoľko riadkov.',
	'forum_texte' => 'Text vášho príspevku',
	'forum_titre' => 'Nadpis',
	'forum_url' => 'Vaša internetová stránka',
	'forum_valider' => 'Potvrdiť výber',
	'forum_voir_avant' => 'Ukážka',
	'forum_votre_email' => 'Vaša e-mailová adresa',
	'forum_votre_nom' => 'Vaše meno',
	'forum_vous_enregistrer' => 'Na to, aby ste mohli diskutovať v tomto diskusnom fóre, musíte byť zaregistrovaný.
 Prosím, zadajte svoj osobný identifikátor.
  ak ste sa ešte nezaregistrovali, musíte',
	'forum_vous_inscrire' => 'sa zaregistrovať.',

	// I
	'icone_bruler_message' => 'Označiť ako spam',
	'icone_bruler_messages' => 'Označiť ako spam',
	'icone_legitimer_message' => 'Označiť ako prípustný',
	'icone_poster_message' => 'Poslať príspevok',
	'icone_suivi_forum' => 'Sledovanie verejného diskusného fóra: @nb_forums@ príspevok (-kov)',
	'icone_suivi_forums' => 'Riadiť diskusné fóra',
	'icone_supprimer_message' => 'Odstrániť tento príspevok',
	'icone_supprimer_messages' => 'Vymazať tieto príspevky',
	'icone_valider_message' => 'Schváliť príspevok',
	'icone_valider_messages' => 'Potvrdiť tieto príspevky',
	'icone_valider_repondre_message' => 'Potvrdiť tento príspevok a reagovať naň',
	'info_1_message_forum' => '1 príspevok v diskusnom fóre',
	'info_activer_forum_public' => '<i>Ak chcete povoliť verejné diskusné fóra, prosím, uveďte predvolený spôsob ich riadenia:</i>',
	'info_appliquer_choix_moderation' => 'Použiť tento výber riadenia:',
	'info_config_forums_prive' => 'V súkromnej zóne môžete aktivovať rôzne typy diskusných fór:',
	'info_config_forums_prive_admin' => 'Diskusné fórum vyhradené pre administrátorov:',
	'info_config_forums_prive_global' => 'Globálne diskusné fórum otvorené všetkým autorom:',
	'info_config_forums_prive_objets' => 'Diskusné fórum pripojené ku každému článku, každej novinke, odkazovanej stránke, atď.:',
	'info_desactiver_forum_public' => 'Deaktivovať používanie verejných
 diskusných fór. Verejné diskusné fóra sa dajú povoliť na individuálnej báze
 pri článkoch; budú zakázané pre rubriky, novinky a pod.',
	'info_envoi_forum' => 'Posielať príspevky z diskusného fóra príslušným autorom',
	'info_fonctionnement_forum' => 'Operácia diskusného fóra:',
	'info_forums_liees_mot' => 'Príspevky v diskusnom fóre s týmto slovom',
	'info_gauche_suivi_forum_2' => 'Stránka na <i>sledovanie diskusných fór</i> je nástroj na riadenie vašej stránky (nie diskusií alebo úprav). Zobrazuje všetky príspevky do diskusných fór (tak na verejnej stránke, ako aj v súkromnej zóne) a umožňuje vám o týchto príspevkoch rozhodovať.',
	'info_liens_syndiques_3' => 'diskusné fóra',
	'info_liens_syndiques_4' => 'je/sú',
	'info_liens_syndiques_5' => 'diskusné fórum',
	'info_liens_syndiques_6' => 'je',
	'info_liens_syndiques_7' => 'čaká na schválenie.',
	'info_liens_texte' => 'Obsah odkazu (-ov) v texte príspevku',
	'info_liens_titre' => 'Obsah odkazu (-ov) v názve príspevku',
	'info_mode_fonctionnement_defaut_forum_public' => 'Predvolený režim verejných diskusných fór',
	'info_nb_messages_forum' => '@nb@ príspevkov v diskusnom fóre',
	'info_option_email' => 'Keď návštevník pošle príspevok do diskusného fóra článku, autor článku môže byť o tom informovaný e-mailom. Pre každý typ diskusného fóra uveďte, či sa má táto možnosť aktivovať.',
	'info_pas_de_forum' => 'žiadne diskusné fórum',
	'info_question_visiteur_ajout_document_forum' => 'Ak chcete povoliť návštevníkom pripájať súbory (obrázky, zvuky a i.) k diskusným príspevkom, určte, ktoré prípony súborov budú akceptované (napr. gif, jpg, png, mp3).',
	'info_question_visiteur_ajout_document_forum_format' => 'Ak chcete povoliť všetky typy súborov, ktoré SPIP považuje za bezpečné, použite hviezdičku. Ak nechcete povoliť žiadne, nerobte nič.',
	'info_selectionner_message' => 'Vybrať príspevky:',
	'interface_formulaire' => 'Rozhranie formulára',
	'interface_onglets' => 'Rozhranie s tabulátormi',
	'item_activer_forum_administrateur' => 'Povoliť diskusné fórum administrátorov',
	'item_config_forums_prive_global' => 'Aktivovať diskusné fórum autorov',
	'item_config_forums_prive_objets' => 'Aktivovať tieto diskusné fóra',
	'item_desactiver_forum_administrateur' => 'Deaktivovať diskusné fórum administrátorov',
	'item_non_config_forums_prive_global' => 'Deaktivovať diskusné fórum autorov',
	'item_non_config_forums_prive_objets' => 'Deaktivovať tieto diskusné fóra',

	// L
	'label_selectionner' => 'Vybrať:',
	'lien_reponse_article' => 'Komentovať tento článok',
	'lien_reponse_breve_2' => 'Komentovať túto novinku',
	'lien_reponse_message' => 'Reagovať na príspevok',
	'lien_reponse_rubrique' => 'Komentovať túto rubriku',
	'lien_reponse_site_reference' => 'Reakcia na odkazovanú stránku',
	'lien_vider_selection' => 'Zrušiť výber',

	// M
	'messages_aucun' => 'Žiadne',
	'messages_meme_auteur' => 'Všetky príspevky od tohto autora',
	'messages_meme_email' => 'Všetky príspevky z tohto e-mailu',
	'messages_meme_ip' => 'Všetky príspevky z tejto IP',
	'messages_off' => 'Vymazané',
	'messages_perso' => 'Súkromné',
	'messages_privadm' => 'Administrátori',
	'messages_prive' => 'Súkromné',
	'messages_privoff' => 'Vymazané',
	'messages_privrac' => 'Všeobecné',
	'messages_prop' => 'Odoslané',
	'messages_publie' => 'Publikované',
	'messages_spam' => 'Spam',
	'messages_tous' => 'Všetky',

	// O
	'onglet_messages_internes' => 'Súkromné správy',
	'onglet_messages_publics' => 'Verejné správy',
	'onglet_messages_vide' => 'Správy bez textu',

	// R
	'repondre_message' => 'Odpovedať na túto správu',

	// S
	'statut_off' => 'Vymazaný',
	'statut_original' => 'pôvodný',
	'statut_prop' => 'Odoslaný',
	'statut_publie' => 'Publikovaný',
	'statut_spam' => 'Spam',

	// T
	'text_article_propose_publication_forum' => 'K tomuto článku môžete napísať komentár v diskusnom fóre, ktoré sa nachádza pod ním.',
	'texte_en_cours_validation' => 'Články, novinky, diskusné fóra uvedené nižšie boli odoslané na publikovanie.',
	'texte_en_cours_validation_forum' => 'V pripojených diskusných fórach môžete smelo napísať komentár.',
	'texte_messages_publics' => 'Verejné príspevky na:',
	'titre_cadre_forum_administrateur' => 'Súkromné diskusné fórum administrátorov',
	'titre_cadre_forum_interne' => 'Interné diskusné fórum',
	'titre_config_forums_prive' => 'Diskusné fóra v súkromnej zóne',
	'titre_forum' => 'Diskusné fórum',
	'titre_forum_suivi' => 'Sledovanie diskusných fór',
	'titre_page_forum_suivi' => 'Sledovanie diskusných fór',
	'titre_selection_action' => 'Výber',
	'tout_voir' => 'Zobraziť všetky príspevky',

	// V
	'voir_messages_objet' => 'Zobraziť príspevky'
);

?>

==> spip_3.0.11.orig.tar.xz: spip-3.0.11.orig/plugins-dist/forum/lang/forum_sk.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/forum?lang_cible=sk
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'aucun_message_forum' => 'Žiaden príspevok v diskusnom fóre',

	// B
	'bouton_radio_articles_futurs' => 'len pre budúce články (žiadna zmena databázy).',
	'bouton_radio_articles_tous' => 'pre všetky články bez výnimky.',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'pre všetky články, okrem tých s deaktivovanými diskusnými fórami.',
	'bouton_radio_enregistrement_obligatoire' => 'Vyžaduje sa registrácia (
  používatelia sa musia zaregistrovať uvedením svojej e-mailovej adresy predtým,
  ako budú môcť posielať príspevky).',
	'bouton_radio_moderation_priori' => 'Kontrola pred zverejnením (príspevky sa zobrazia až potom, čo ich
 schvália administrátori).',
	'bouton_radio_modere_abonnement' => 'Vyžaduje sa registrácia',
	'bouton_radio_modere_posteriori' => 'kontrola po zverejnení',
	'bouton_radio_modere_priori' => 'kontrola pred zverejnením',
	'bouton_radio_publication_immediate' => 'Okamžité publikovanie príspevkov
 (príspevky sa zobrazia len čo budú odoslané; ak bude treba, administrátori
 ich môžu potom odstrániť).',

	// D
	'documents_interdits_forum' => 'Dokumenty nie sú v tomto diskusnom fóre povolené',

	// E
	'erreur_enregistrement_message' => 'Váš príspevok sa z technických príčin nepodarilo uložiť.',

	// F
	'form_pet_message_commentaire' => 'Nejaký príspevok alebo komentáre?',
	'forum' => 'Diskusné fórum',
	'forum_acces_refuse' => 'K týmto diskusným fóram už viac nemáte prístup.',
	'forum_attention_dix_caracteres' => '<b>Upozornenie!</b> Váš príspevok musí mať aspoň 10 znakok.',
	'forum_attention_message_non_poste' => 'Pozor, neodoslali ste svoj príspevok!',
	'forum_attention_nb_caracteres_mini' => '<b>Pozor!</b> Váš príspevok musí mať aspoň @min@ znakov.',
	'forum_attention_trois_caracteres' => '<b>Upozornenie!</b> Názov musí mať aspoň 3 znaky.',
	'forum_attention_trop_caracteres' => '<b>Pozor!</b> váš príspevok je pridlhý (@compte@ znamkov): aby ste ho mohli uložiť, príspevok nesmie mať viac ako @max@ znakov.',
	'forum_avez_selectionne' => 'Vybrali ste:',
	'forum_cliquer_retour' => 'Kliknite <a href=\'@retour_forum@\'>sem,</a> aby ste mohli pokračovať.',
	'forum_forum' => 'diskusné fórum',
	'forum_info_modere' => 'Toto diskusné fórum sa kontroluje pred zverejnením: váš príspevok sa zobrazí až potom, čo ho potvrdí administrátor stránky.',
	'forum_lien_hyper' => 'Hypertextový odkaz',
	'forum_message' => 'Váš príspevok',
	'forum_message_definitif' => 'Koniec úprav: poslať príspevok',
	'forum_message_trop_long' => 'Vaša správa je pridlhá. Maximálna dĺžka je 20 000 znakov.',
	'forum_ne_repondez_pas' => 'Neodpovedajte na tento mejl priamo - prosím, použite diskusné fórum:',
	'forum_page_url' => '(If your message refers to an article published on the web or to a page providing further information, please enter the title of the page and its URL below).',
	'forum_permalink' => 'Trvalý odkaz na komentár',
	'forum_poste_par' => 'Príspevok @parauteur@ odoslaný k článku "@titre@".',
	'forum_poste_par_court' => 'Príspevok odoslaný@parauteur@.',
	'forum_poste_par_generique' => 'Príspevok odoslaný@parauteur@ (@objet@ " @titre@ ").',
	'forum_qui_etes_vous' => 'Kto ste?',
	'forum_saisie_texte_info' => 'Tento formulár akceptuje skratky SPIPu <code>[-&gt;url] {{tučné}} {kurzíva} &lt;citácia&gt; &lt;kód&gt;</code> a kód HTML <code>&lt;q&gt; &lt;del&gt; &lt;ins&gt;.</code> Ak chcete vytvoriť odseky, jednoducho vynechajte niekoľko riadkov.',
	'forum_texte' => 'Text vášho príspevku',
	'forum_titre' => 'Nadpis',
	'forum_url' => 'Vaša internetová stránka',
	'forum_valider' => 'Potvrdiť výber',
	'forum_voir_avant' => 'Ukážka',
	'forum_votre_email' => 'Vaša e-mailová adresa',
	'forum_votre_nom' => 'Vaše meno',
	'forum_vous_enregistrer' => 'Na to, aby ste mohli diskutovať v tomto diskusnom fóre, musíte byť zaregistrovaný.
 Prosím, zadajte svoj osobný identifikátor.
  ak ste sa ešte nezaregistrovali, musíte',
	'forum_vous_inscrire' => 'sa zaregistrovať.',

	// I
	'icone_bruler_message' => 'Označiť ako spam',
	'icone_bruler_messages' => 'Označiť ako spam',
	'icone_legitimer_message' => 'Označiť ako prípustný',
	'icone_poster_message' => 'Poslať príspevok',
	'icone_suivi_forum' => 'Sledovanie verejného diskusného fóra: @nb_forums@ príspevok (-kov)',
	'icone_suivi_forums' => 'Riadiť diskusné fóra',
	'icone_supprimer_message' => 'Odstrániť tento príspevok',
	'icone_supprimer_messages' => 'Vymazať tieto príspevky',
	'icone_valider_message' => 'Schváliť príspevok',
	'icone_valider_messages' => 'Potvrdiť tieto príspevky',
	'icone_valider_repondre_message' => 'Potvrdiť tento príspevok a reagovať naň',
	'info_1_message_forum' => '1 príspevok v diskusnom fóre',
	'info_activer_forum_public' => '<i>Ak chcete povoliť verejné diskusné fóra, prosím, uveďte predvolený spôsob ich riadenia:</i>',
	'info_appliquer_choix_moderation' => 'Použiť tento výber riadenia:',
	'info_config_forums_prive' => 'V súkromnej zóne môžete aktivovať rôzne typy diskusných fór:',
	'info_config_forums_prive_admin' => 'Diskusné fórum vyhradené pre administrátorov:',
	'info_config_forums_prive_global' => 'Globálne diskusné fórum otvorené všetkým autorom:',
	'info_config_forums_prive_objets' => 'Diskusné fórum pripojené ku každému článku, každej novinke, odkazovanej stránke, atď.:',
	'info_desactiver_forum_public' => 'Deaktivovať používanie verejných
 diskusných fór. Verejné diskusné fóra sa dajú povoliť na individuálnej báze
 pri článkoch; budú zakázané pre rubriky, novinky a pod.',
	'info_envoi_forum' => 'Posielať príspevky z diskusného fóra príslušným autorom',
	'info_fonctionnement_forum' => 'Nastavenie diskusného fóra:',
	'info_forums_liees_mot' => 'Príspevky v diskusnom fóre s týmto slovom',
	'info_gauche_suivi_forum_2' => 'Stránka na <i>sledovanie diskusných fór</i> je nástroj na riadenie vašej stránky (nie diskusií alebo úprav). Zobrazuje všetky príspevky do diskusných fór (tak na verejnej stránke, ako aj v súkromnej zóne) a umožňuje vám o týchto príspevkoch rozhodovať.',
	'info_liens_syndiques_3' => 'diskusné fóra',
	'info_liens_syndiques_4' => 'je/sú',
	'info_liens_syndiques_5' => 'diskusné fórum',
	'info_liens_syndiques_6' => 'je',
	'info_liens_syndiques_7' => 'čaká na schválenie.',
	'info_liens_texte' => 'Obsah odkazu (-ov) v texte príspevku',
	'info_liens_titre' => 'Obsah odkazu (-ov) v názve príspevku',
	'info_mode_fonctionnement_defaut_forum_public' => 'Predvolený režim verejných diskusných fór',
	'info_nb_messages_forum' => '@nb@ príspevkov v diskusnom fóre',
	'info_option_email' => 'Keď návštevník pošle príspevok do diskusného fóra článku, autor článku môže byť o tom informovaný e-mailom. Pre každý typ diskusného fóra uveďte, či sa má táto možnosť aktivovať.',
	'info_pas_de_forum' => 'žiadne diskusné fórum',
	'info_question_visiteur_ajout_document_forum' => 'Ak chcete povoliť návštevníkom pripájať súbory (obrázky, zvuky a i.) k diskusným príspevkom, určte, ktoré prípony súborov budú akceptované (napr. gif, jpg, png, mp3).',
	'info_question_visiteur_ajout_document_forum_format' => 'Ak chcete povoliť všetky typy súborov, ktoré SPIP považuje za bezpečné, použite hviezdičku. Ak nechcete povoliť žiadne, nerobte nič.',
	'info_selectionner_message' => 'Vybrať príspevky:',
	'interface_formulaire' => 'Rozhranie formulára',
	'interface_onglets' => 'Rozhranie s tabulátormi',
	'item_activer_forum_administrateur' => 'Povoliť diskusné fórum administrátorov',
	'item_config_forums_prive_global' => 'Aktivovať diskusné fórum autorov',
	'item_config_forums_prive_objets' => 'Aktivovať tieto diskusné fóra',
	'item_desactiver_forum_administrateur' => 'Deaktivovať diskusné fórum administrátorov',
	'item_non_config_forums_prive_global' => 'Deaktivovať diskusné fórum autorov',
	'item_non_config_forums_prive_objets' => 'Deaktivovať tieto diskusné fóra',

	// L
	'label_selectionner' => 'Vybrať:',
	'lien_reponse_article' => 'Komentovať tento článok',
	'lien_reponse_breve_2' => 'Komentovať túto novinku',
	'lien_reponse_message' => 'Reagovať na príspevok',
	'lien_reponse_rubrique' => 'Komentovať túto rubriku',
	'lien_reponse_site_reference' => 'Reakcia na odkazovanú stránku',
	'lien_vider_selection' => 'Zrušiť výber',

	// M
	'messages_aucun' => 'Žiadne',
	'messages_meme_auteur' => 'Všetky príspevky od tohto autora',
	'messages_meme_email' => 'Všetky príspevky z tohto e-mailu',
	'messages_meme_ip' => 'Všetky príspevky z tejto IP',
	'messages_off' => 'Vymazané',
	'messages_perso' => 'Súkromné',
	'messages_privadm' => 'Administrátori',
	'messages_prive' => 'Súkromné',
	'messages_privoff' => 'Vymazané',
	'messages_privrac' => 'Všeobecné',
	'messages_prop' => 'Odoslané',
	'messages_publie' => 'Publikované',
	'messages_spam' => 'Spam',
	'messages_tous' => 'Všetky',

	// O
	'onglet_messages_internes' => 'Súkromné správy',
	'onglet_messages_publics' => 'Verejné správy',
	'onglet_messages_vide' => 'Správy bez textu',

	// R
	'repondre_message' => 'Odpovedať na túto správu',

	// S
	'statut_off' => 'Vymazaný',
	'statut_original' => 'pôvodný',
	'statut_prop' => 'Odoslaný',
	'statut_publie' => 'Publikovaný',
	'statut_spam' => 'Spam',

	// T
	'text_article_propose_publication_forum' => 'K tomuto článku môžete napísať komentár v diskusnom fóre, ktoré sa nachádza pod ním.',
	'texte_en_cours_validation' => 'Články, novinky, diskusné fóra uvedené nižšie boli odoslané na publikovanie.',
	'texte_en_cours_validation_forum' => 'V pripojených diskusných fórach môžete smelo napísať komentár.',
	'texte_messages_publics' => 'Verejné príspevky na:',
	'titre_cadre_forum_administrateur' => 'Súkromné diskusné fórum administrátorov',
	'titre_cadre_forum_interne' => 'Interné diskusné fórum',
	'titre_config_forums_prive' => 'Diskusné fóra v súkromnej zóne',
	'titre_forum' => 'Diskusné fórum',
	'titre_forum_suivi' => 'Sledovanie diskusných fór',
	'titre_page_forum_suivi' => 'Sledovanie diskusných fór',
	'titre_selection_action' => 'Výber',
	'tout_voir' => 'Zobraziť všetky príspevky',

	// V
	'voir_messages_objet' => 'Zobraziť príspevky'
);

?>
